pub enum Error {
UnexpectedEndOfStream,
UnexpectedData(usize),
InvalidValue,
InvalidChar(Vec<u8>, usize),
InvalidString(Vec<String>, usize),
InvalidNumber(usize),
}Expand description
List of all errors.
Variants
UnexpectedEndOfStream
An input data ended earlier than expected.
Should only appear on invalid input data. Errors in a valid XML should be handled by errors below.
UnexpectedData(usize)
An input text contains unknown data.
InvalidValue
A provided string doesn’t have a valid data.
For example, if we try to parse a color form zzz
string - we will get this error.
But if we try to parse a number list like 1.2 zzz,
then we will get InvalidNumber, because at least some data is valid.
InvalidChar(Vec<u8>, usize)
An invalid/unexpected character.
The first byte is an actual one, others - expected.
We are using a single value to reduce the struct size.
InvalidString(Vec<String>, usize)
An unexpected character instead of an XML space.
The first string is an actual one, others - expected.
We are using a single value to reduce the struct size.
InvalidNumber(usize)
An invalid number.