pub struct AspectRatio {
pub defer: bool,
pub align: Align,
pub slice: bool,
}Expand description
Representation of the preserveAspectRatio attribute.
SVG 2 removed the defer keyword, but we still support it.
Fields
defer: bool<defer> value.
Set to true when defer value is present.
align: Align<align> value.
slice: bool<meetOrSlice> value.
- Set to
truewhenslicevalue is present. - Set to
falsewhenmeetvalue is present or value is not set at all.