FuncIRI

Struct FuncIRI 

pub struct FuncIRI<'a>(pub &'a str);
Representation of the <FuncIRI> type.

Tuple Fields

0: &'a str

Implementations

Source

impl<'a> FuncIRI<'a>

pub fn from_str(text: &'a str) -> Result<FuncIRI<'a>, Error>

Parsers a FuncIRI from a string.

By the SVG spec, the ID must contain only Name characters, but since no one fallows this it will parse any characters.

We can’t use the FromStr trait because it requires an owned value as a return type.